/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x2,0xc,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xe3,0x6,0x15,0x10,0x0,0x86,0x54,0x3d,0x1e,0x30,0x91,0x1b,
  0x8f,0x48,0x49,0xf8,0x73,0xc9,0x47,0xbf,0x25,0xfd,0x32,0x6d,0xe3,0xca,0xc9,0xc9,
  0x1b,0x8c,0x86,0xe3,0xe,0xe5,0xa4,0x0,0x23,0x45,0x5,0x35,0x0,0x34,0x0,0x33,
  0x0,0x1c,0x19,0xfc,0xb7,0xff,0x9a,0x7a,0x0,0x90,0x60,0x10,0x78,0x1e,0xa7,0xe4,
  0x30,0xc6,0x2c,0x6f,0xc6,0xde,0xc2,0x8,0x8f,0x6f,0xb5,0x7e,0x39,0xb0,0x39,0xb,
  0xf4,0x74,0xf5,0x78,0x2f,0xcd,0x3b,0x3b,0xc5,0x6f,0xd6,0x98,0xd0,0x6a,0x5,0xb2,
  0xbc,0x9f,0x6d,0x51,0xdb,0x5,0xf,0x59,0x51,0xa1,0x72,0xca,0x24,0x6c,0xed,0x91,
  0xee,0x86,0x1d,0x3f,0x96,0x34,0x9e,0x3e,0x31,0x3,0xc2,0x95,0x5e,0xf3,0xa7,0x73,
  0xae,0x5e,0x47,0x8d,0x42,0x79,0x6e,0xc4,0xf7,0xbb,0x13,0xbe,0x9a,0x6c,0x8e,0x87,
  0xfc,0xbe,0x56,0x3a,0x5c,0x9c,0x5a,0xc1,0x61,0x1,0xfb,0xde,0x97,0x5b,0xa8,0x32,
  0xa8,0x56,0xb7,0xe4,0x83,0xef,0xa5,0x23,0x8,0x5b,0x52,0xbd,0x9e,0x94,0x87,0x69,
  0xbd,0xda,0xf,0x94,0xe7,0x89,0xc1,0xe2,0x4b,0x36,0x3c,0xa7,0x55,0x76,0xb,0x5d,
  0x7d,0xb1,0x21,0xbe,0x9a,0xab,0x88,0x6f,0x25,0xeb,0xb5,0xc6,0x3b,0x8e,0x53,0xa1,
  0x38,0x3e,0xfe,0xf1,0x40,0x7d,0x7b,0xad,0x6e,0x9b,0x62,0x1f,0x5e,0x5f,0xae,0xa9,
  0xd7,0xff,0x91,0xd2,0x6e,0xef,0x76,0x65,0x10,0xea,0x19,0xf5,0xbf,0x35,0xb4,0x6f,
  0xd5,0x96,0x12,0x59,0xe7,0xf6,0x17,0x98,0x65,0x49,0xcb,0xd,0x7b,0x2b,0xd6,0xe5,
  0xb,0x7e,0xa8,0x41,0x96,0x11,0xaa,0x9a,0x30,0x49,0xa1,0x30,0x8d,0x1,0x20,0x44,
  0xa8,0xd4,0xda,0x1c,0x72,0x20,0x38,0xa2,0xa3,0x68,0x6,0x41,0x19,0x43,0x4,0xc8,
  0xc0,0x44,0x66,0x29,0x28,0x29,0x28,0xaa,0xe,0x8a,0xce,0xef,0x48,0x38,0x3f,0x37,
  0xd3,0x23,0xf6,0xc6,0x54,0x1,0x19,0x63,0xa4,0xfc,0x13,0x37,0x6c,0x59,0x83,0x70,
  0xbd,0x4,0xac,0x6b,0x72,0x97,0x9c,0x38,0x58,0x3f,0x8b,0x49,0xeb,0xaa,0xbb,0x1b,
  0x22,0xfb,0xc4,0x91,0x1,0x46,0xdb,0x20,0x6f,0x49,0xd6,0xd5,0x63,0x84,0x81,0xdb,
  0x8c,0x5b,0xf7,0xca,0xe9,0x87,0x82,0x45,0x4a,0x28,0xd2,0x21,0x50,0x7e,0xdc,0xa2,
  0x25,0x13,0xb0,0xc4,0x32,0x88,0x56,0xc4,0xcf,0xd9,0x13,0xbe,0x6,0x11,0x1c,0xec,
  0xde,0x3c,0xb6,0x8d,0x15,0x36,0xc0,0xb4,0xb0,0xba,0x94,0xf2,0x7a,0xe1,0x1e,0x76,
  0x58,0xa7,0xb5,0x89,0x5f,0xed,0x9f,0xb9,0xad,0xf2,0xbf,0x45,0xd6,0x79,0x88,0x9d,
  0x7e,0x50,0x45,0xad,0xc6,0x6d,0xc,0xe3,0xd,0xb9,0x7b,0xef,0xb1,0x6a,0xd3,0x72,
  0x4f,0xba,0xf9,0x43,0x11,0xcb,0x58,0x62,0x7e,0xd3,0xc0,0xbd,0x41,0x57,0x6d,0x82,
  0x82,0xaf,0x90,0x13,0x85,0xc,0xca,0x0,0x78,0x65,0x24,0x52,0xec,0xff,0xd5,0x82,
  0x13,0x6d,0x4f,0x3b,0x70,0x67,0x63,0xe5,0x59,0xec,0x41,0xae,0xe0,0x48,0xc0,0x52,
  0x9,0xa0,0x31,0x9b,0x44,0x31,0xbe,0x61,0x31,0x10,0xc4,0xf8,0xe9,0x73,0x8,0xd9,
  0x11,0x3e,0xb,0xbc,0x3a,0xd8,0x9c,0xbf,0x1a,0x8d,0x5f,0x20,0x1b,0xa9,0x83,0xc2,
  0x49,0x0,0x28,0xd1,0x86,0xd2,0x92,0xcb,0x42,0xae,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // org
  0x0,0x3,
  0x0,0x0,0x76,0x87,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,
    // kde
  0x0,0x3,
  0x0,0x0,0x71,0xa5,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,
    // audiotube
  0x0,0x9,
  0xb,0x6,0x6a,0xe5,
  0x0,0x61,
  0x0,0x75,0x0,0x64,0x0,0x69,0x0,0x6f,0x0,0x74,0x0,0x75,0x0,0x62,0x0,0x65,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9e,0x91,0xd3,0xda,0xe8,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9e,0x91,0xd3,0xda,0xe8,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9e,0x91,0xd3,0xda,0xe8,
  // :/qt/qml/org
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9e,0x91,0xd3,0xda,0xe8,
  // :/qt/qml/org/kde
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9e,0x91,0xd3,0xda,0xe8,
  // :/qt/qml/org/kde/audiotube
  0x0,0x0,0x0,0x2e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9e,0x91,0xd3,0xda,0xe8,
  // :/qt/qml/org/kde/audiotube/qmldir
  0x0,0x0,0x0,0x46,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9e,0x91,0xd3,0xda,0xe8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_audiotube)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_audiotube)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_audiotube)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_audiotube)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_org_kde_audiotube)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_org_kde_audiotube)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
