/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<abstractshelfmodel.h>)
#  include <abstractshelfmodel.h>
#endif
#if __has_include(<albummodel.h>)
#  include <albummodel.h>
#endif
#if __has_include(<artistmodel.h>)
#  include <artistmodel.h>
#endif
#if __has_include(<blur.h>)
#  include <blur.h>
#endif
#if __has_include(<clipboard.h>)
#  include <clipboard.h>
#endif
#if __has_include(<errorhandler.h>)
#  include <errorhandler.h>
#endif
#if __has_include(<exploremodel.h>)
#  include <exploremodel.h>
#endif
#if __has_include(<foreigntypes.h>)
#  include <foreigntypes.h>
#endif
#if __has_include(<homemodel.h>)
#  include <homemodel.h>
#endif
#if __has_include(<library.h>)
#  include <library.h>
#endif
#if __has_include(<localplaylistmodel.h>)
#  include <localplaylistmodel.h>
#endif
#if __has_include(<localplaylistsmodel.h>)
#  include <localplaylistsmodel.h>
#endif
#if __has_include(<lyricsmodel.h>)
#  include <lyricsmodel.h>
#endif
#if __has_include(<playerutils.h>)
#  include <playerutils.h>
#endif
#if __has_include(<playlistimporter.h>)
#  include <playlistimporter.h>
#endif
#if __has_include(<playlistmodel.h>)
#  include <playlistmodel.h>
#endif
#if __has_include(<searchmodel.h>)
#  include <searchmodel.h>
#endif
#if __has_include(<stateconfig.h>)
#  include <stateconfig.h>
#endif
#if __has_include(<thumbnailsource.h>)
#  include <thumbnailsource.h>
#endif
#if __has_include(<userplaylistmodel.h>)
#  include <userplaylistmodel.h>
#endif
#if __has_include(<videoinfoextractor.h>)
#  include <videoinfoextractor.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_audiotube()
{
    qmlRegisterModule("org.kde.audiotube", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<AbstractShelfModel *>().id();
    QMetaType::fromType<AbstractYTMusicModel *>().id();
    qmlRegisterTypesAndRevisions<AlbumModel>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<ArtistModel>("org.kde.audiotube", 254);
    qmlRegisterEnum<ArtistModel::Type>("ArtistModel::Type");
    qmlRegisterTypesAndRevisions<Blur>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<Clipboard>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<ErrorHandler>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<ExploreModel>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<FavouriteWatcher>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<HomeModel>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<HomeShelfModel>("org.kde.audiotube", 254);
    qmlRegisterEnum<HomeShelfModel::Role>("HomeShelfModel::Role");
    qmlRegisterTypesAndRevisions<Library>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<LocalPlaylistModel>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<LocalPlaylistsModel>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<LocalSearchModel>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<LyricsModel>("org.kde.audiotube", 254);
    qmlRegisterEnum<LyricsModel::Role>("LyricsModel::Role");
    qmlRegisterTypesAndRevisions<MoodPlaylistsModel>("org.kde.audiotube", 254);
    qmlRegisterEnum<MoodPlaylistsModel::Role>("MoodPlaylistsModel::Role");
    qmlRegisterTypesAndRevisions<MprisForeign>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<MprisPlayerForeign>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<PlaybackHistoryModel>("org.kde.audiotube", 254);
    qmlRegisterEnum<PlaybackHistoryModel::Roles>("PlaybackHistoryModel::Roles");
    qmlRegisterTypesAndRevisions<PlayerUtils>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<PlaylistImporter>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<PlaylistModel>("org.kde.audiotube", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<SearchModel>("org.kde.audiotube", 254);
    qmlRegisterEnum<SearchModel::Type>("SearchModel::Type");
    qmlRegisterTypesAndRevisions<StateConfig>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<ThumbnailSource>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<UserPlaylistModel>("org.kde.audiotube", 254);
    qmlRegisterEnum<UserPlaylistModel::Role>("UserPlaylistModel::Role");
    qmlRegisterTypesAndRevisions<VideoInfoExtractor>("org.kde.audiotube", 254);
    qmlRegisterTypesAndRevisions<WasPlayedWatcher>("org.kde.audiotube", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.audiotube", 254, 254);
}

static const QQmlModuleRegistration orgkdeaudiotubeRegistration("org.kde.audiotube", qml_register_types_org_kde_audiotube);
