/****************************************************************************
** Meta object code from reading C++ file 'abstractshelfmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../audiotube-26.04.2/src/abstractshelfmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractshelfmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14HomeShelfModelE_t {};
} // unnamed namespace

template <> constexpr inline auto HomeShelfModel::qt_create_metaobjectdata<qt_meta_tag_ZN14HomeShelfModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HomeShelfModel",
        "QML.Element",
        "auto",
        "openAlbum",
        "",
        "browseId",
        "openArtist",
        "radioId",
        "shuffleId",
        "openPlaylist",
        "openSong",
        "videoId",
        "openVideo",
        "title",
        "openMood",
        "params",
        "triggerItem",
        "row",
        "Role",
        "Title",
        "TypeRole",
        "VideoId",
        "Artists",
        "RadioPlaylistId",
        "ThumbnailUrl",
        "ArtistsDisplayString"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openAlbum'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'openArtist'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'openPlaylist'
        QtMocHelpers::SignalData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'openSong'
        QtMocHelpers::SignalData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'openVideo'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'openMood'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::QString, 15 },
        }}),
        // Method 'triggerItem'
        QtMocHelpers::MethodData<void(int)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(18, 18, QMC::EnumFlags{}).add({
            {   19, Role::Title },
            {   20, Role::TypeRole },
            {   21, Role::VideoId },
            {   22, Role::Artists },
            {   23, Role::RadioPlaylistId },
            {   24, Role::ThumbnailUrl },
            {   25, Role::ArtistsDisplayString },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<HomeShelfModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject HomeShelfModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HomeShelfModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HomeShelfModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14HomeShelfModelE_t>.metaTypes,
    nullptr
} };

void HomeShelfModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HomeShelfModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openAlbum((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->openArtist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->openPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->openSong((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->openVideo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->openMood((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->triggerItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HomeShelfModel::*)(const QString & )>(_a, &HomeShelfModel::openAlbum, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HomeShelfModel::*)(const QString & , const QString & , const QString & )>(_a, &HomeShelfModel::openArtist, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (HomeShelfModel::*)(const QString & )>(_a, &HomeShelfModel::openPlaylist, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (HomeShelfModel::*)(const QString & )>(_a, &HomeShelfModel::openSong, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (HomeShelfModel::*)(const QString & , const QString & )>(_a, &HomeShelfModel::openVideo, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (HomeShelfModel::*)(const QString & , const QString & )>(_a, &HomeShelfModel::openMood, 5))
            return;
    }
}

const QMetaObject *HomeShelfModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HomeShelfModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14HomeShelfModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int HomeShelfModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void HomeShelfModel::openAlbum(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void HomeShelfModel::openArtist(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void HomeShelfModel::openPlaylist(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void HomeShelfModel::openSong(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void HomeShelfModel::openVideo(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void HomeShelfModel::openMood(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN18AbstractShelfModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractShelfModel::qt_create_metaobjectdata<qt_meta_tag_ZN18AbstractShelfModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractShelfModel",
        "openAlbum",
        "",
        "browseId",
        "openArtist",
        "radioId",
        "shuffleId",
        "openPlaylist",
        "openSong",
        "videoId",
        "openVideo",
        "title",
        "openMood",
        "params"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openAlbum'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'openArtist'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'openPlaylist'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'openSong'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'openVideo'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'openMood'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractShelfModel, qt_meta_tag_ZN18AbstractShelfModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractShelfModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractYTMusicModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AbstractShelfModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AbstractShelfModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18AbstractShelfModelE_t>.metaTypes,
    nullptr
} };

void AbstractShelfModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractShelfModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openAlbum((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->openArtist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->openPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->openSong((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->openVideo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->openMood((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractShelfModel::*)(const QString & )>(_a, &AbstractShelfModel::openAlbum, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractShelfModel::*)(const QString & , const QString & , const QString & )>(_a, &AbstractShelfModel::openArtist, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractShelfModel::*)(const QString & )>(_a, &AbstractShelfModel::openPlaylist, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractShelfModel::*)(const QString & )>(_a, &AbstractShelfModel::openSong, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractShelfModel::*)(const QString & , const QString & )>(_a, &AbstractShelfModel::openVideo, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractShelfModel::*)(const QString & , const QString & )>(_a, &AbstractShelfModel::openMood, 5))
            return;
    }
}

const QMetaObject *AbstractShelfModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractShelfModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AbstractShelfModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractYTMusicModel::qt_metacast(_clname);
}

int AbstractShelfModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractYTMusicModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void AbstractShelfModel::openAlbum(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractShelfModel::openArtist(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void AbstractShelfModel::openPlaylist(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AbstractShelfModel::openSong(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AbstractShelfModel::openVideo(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void AbstractShelfModel::openMood(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
