/****************************************************************************
** Meta object code from reading C++ file 'mprisplayer_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../audiotube-26.04.2/src/qtmpris/src/mprisplayer_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mprisplayer_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16MprisRootAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto MprisRootAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN16MprisRootAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MprisRootAdaptor",
        "D-Bus Interface",
        "org.mpris.MediaPlayer2",
        "D-Bus Introspection",
        "  <interface name=\"org.mpris.MediaPlayer2\">\n    <method name=\""
        "Raise\"/>\n    <method name=\"Quit\"/>\n    <property access=\"rea"
        "d\" type=\"b\" name=\"CanQuit\"/>\n    <property access=\"readwrit"
        "e\" type=\"b\" name=\"Fullscreen\"/>\n    <property access=\"read\""
        " type=\"b\" name=\"CanSetFullscreen\"/>\n    <property access=\"re"
        "ad\" type=\"b\" name=\"CanRaise\"/>\n    <property access=\"read\""
        " type=\"b\" name=\"HasTrackList\"/>\n    <property access=\"read\""
        " type=\"s\" name=\"Identity\"/>\n    <property access=\"read\" typ"
        "e=\"s\" name=\"DesktopEntry\"/>\n    <property access=\"read\" typ"
        "e=\"as\" name=\"SupportedUriSchemes\"/>\n    <property access=\"re"
        "ad\" type=\"as\" name=\"SupportedMimeTypes\"/>\n  </interface>\n",
        "Quit",
        "",
        "Raise",
        "onCanQuitChanged",
        "onCanRaiseChanged",
        "onCanSetFullscreenChanged",
        "onDesktopEntryChanged",
        "onFullscreenChanged",
        "onHasTrackListChanged",
        "onIdentityChanged",
        "onSupportedUriSchemesChanged",
        "onSupportedMimeTypesChanged",
        "CanQuit",
        "CanRaise",
        "CanSetFullscreen",
        "DesktopEntry",
        "Fullscreen",
        "HasTrackList",
        "Identity",
        "SupportedMimeTypes",
        "SupportedUriSchemes"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Quit'
        QtMocHelpers::SlotData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Raise'
        QtMocHelpers::SlotData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCanQuitChanged'
        QtMocHelpers::SlotData<void() const>(8, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCanRaiseChanged'
        QtMocHelpers::SlotData<void() const>(9, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCanSetFullscreenChanged'
        QtMocHelpers::SlotData<void() const>(10, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDesktopEntryChanged'
        QtMocHelpers::SlotData<void() const>(11, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFullscreenChanged'
        QtMocHelpers::SlotData<void() const>(12, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onHasTrackListChanged'
        QtMocHelpers::SlotData<void() const>(13, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onIdentityChanged'
        QtMocHelpers::SlotData<void() const>(14, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSupportedUriSchemesChanged'
        QtMocHelpers::SlotData<void() const>(15, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSupportedMimeTypesChanged'
        QtMocHelpers::SlotData<void() const>(16, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanQuit'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanRaise'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanSetFullscreen'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'DesktopEntry'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Fullscreen'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'HasTrackList'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Identity'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SupportedMimeTypes'
        QtMocHelpers::PropertyData<QStringList>(24, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'SupportedUriSchemes'
        QtMocHelpers::PropertyData<QStringList>(25, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MprisRootAdaptor, qt_meta_tag_ZN16MprisRootAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MprisRootAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MprisRootAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MprisRootAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16MprisRootAdaptorE_t>.metaTypes,
    nullptr
} };

void MprisRootAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisRootAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Quit(); break;
        case 1: _t->Raise(); break;
        case 2: _t->onCanQuitChanged(); break;
        case 3: _t->onCanRaiseChanged(); break;
        case 4: _t->onCanSetFullscreenChanged(); break;
        case 5: _t->onDesktopEntryChanged(); break;
        case 6: _t->onFullscreenChanged(); break;
        case 7: _t->onHasTrackListChanged(); break;
        case 8: _t->onIdentityChanged(); break;
        case 9: _t->onSupportedUriSchemesChanged(); break;
        case 10: _t->onSupportedMimeTypesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canQuit(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canRaise(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canSetFullscreen(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->desktopEntry(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasTrackList(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->identity(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->supportedMimeTypes(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->supportedUriSchemes(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setFullscreen(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MprisRootAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisRootAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16MprisRootAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MprisRootAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN18MprisPlayerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto MprisPlayerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18MprisPlayerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MprisPlayerAdaptor",
        "D-Bus Interface",
        "org.mpris.MediaPlayer2.Player",
        "D-Bus Introspection",
        "  <interface name=\"org.mpris.MediaPlayer2.Player\">\n    <method "
        "name=\"Next\"/>\n    <method name=\"Previous\"/>\n    <method name"
        "=\"Pause\"/>\n    <method name=\"PlayPause\"/>\n    <method name=\""
        "Stop\"/>\n    <method name=\"Play\"/>\n    <method name=\"Seek\">\n"
        "      <arg direction=\"in\" type=\"x\" name=\"Offset\"/>\n    </me"
        "thod>\n    <method name=\"SetPosition\">\n      <arg direction=\"i"
        "n\" type=\"o\" name=\"TrackId\"/>\n      <arg direction=\"in\" typ"
        "e=\"x\" name=\"Position\"/>\n    </method>\n    <method name=\"Ope"
        "nUri\">\n      <arg direction=\"in\" type=\"s\" name=\"Uri\"/>\n  "
        "    <annotation value=\"QUrl\" name=\"org.qtproject.QtDBus.QtTypeN"
        "ame.In0\"/>\n    </method>\n    <signal name=\"Seeked\">\n      <a"
        "rg direction=\"out\" type=\"x\" name=\"Position\"/>\n    </signal>"
        "\n    <property access=\"read\" type=\"s\" name=\"PlaybackStatus\""
        "/>\n    <property access=\"readwrite\" type=\"s\" name=\"LoopStatu"
        "s\"/>\n    <property access=\"readwrite\" type=\"d\" name=\"Rate\""
        "/>\n    <property access=\"readwrite\" type=\"b\" name=\"Shuffle\""
        "/>\n    <property access=\"read\" type=\"a{sv}\" name=\"Metadata\""
        ">\n      <annotation value=\"QVariantMap\" name=\"org.qtproject.Qt"
        "DBus.QtTypeName\"/>\n    </property>\n    <property access=\"readw"
        "rite\" type=\"d\" name=\"Volume\"/>\n    <property access=\"read\""
        " type=\"x\" name=\"Position\">\n      <annotation value=\"false\" "
        "name=\"org.freedesktop.DBus.Property.EmitsChangedSignal\"/>\n    <"
        "/property>\n    <property access=\"read\" type=\"d\" name=\"Minimu"
        "mRate\"/>\n    <property access=\"read\" type=\"d\" name=\"Maximum"
        "Rate\"/>\n    <property access=\"read\" type=\"b\" name=\"CanGoNex"
        "t\"/>\n    <property access=\"read\" type=\"b\" name=\"CanGoPrevio"
        "us\"/>\n    <property access=\"read\" type=\"b\" name=\"CanPlay\"/"
        ">\n    <property access=\"read\" type=\"b\" name=\"CanPause\"/>\n "
        "   <property access=\"read\" type=\"b\" name=\"CanSeek\"/>\n    <p"
        "roperty access=\"read\" type=\"b\" name=\"CanControl\">\n      <an"
        "notation value=\"false\" name=\"org.freedesktop.DBus.Property.Emit"
        "sChangedSignal\"/>\n    </property>\n  </interface>\n",
        "Seeked",
        "",
        "Position",
        "Next",
        "OpenUri",
        "Uri",
        "Pause",
        "Play",
        "PlayPause",
        "Previous",
        "Seek",
        "Offset",
        "SetPosition",
        "QDBusObjectPath",
        "TrackId",
        "Stop",
        "onCanControlChanged",
        "onCanGoNextChanged",
        "onCanGoPreviousChanged",
        "onCanPauseChanged",
        "onCanPlayChanged",
        "onCanSeekChanged",
        "onLoopStatusChanged",
        "onMaximumRateChanged",
        "onMetadataChanged",
        "onMinimumRateChanged",
        "onPlaybackStatusChanged",
        "onRateChanged",
        "onShuffleChanged",
        "onVolumeChanged",
        "CanControl",
        "CanGoNext",
        "CanGoPrevious",
        "CanPause",
        "CanPlay",
        "CanSeek",
        "LoopStatus",
        "MaximumRate",
        "Metadata",
        "QVariantMap",
        "MinimumRate",
        "PlaybackStatus",
        "Rate",
        "Shuffle",
        "Volume"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Seeked'
        QtMocHelpers::SignalData<void(qlonglong)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 7 },
        }}),
        // Slot 'Next'
        QtMocHelpers::SlotData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'OpenUri'
        QtMocHelpers::SlotData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'Pause'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Play'
        QtMocHelpers::SlotData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PlayPause'
        QtMocHelpers::SlotData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Previous'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Seek'
        QtMocHelpers::SlotData<void(qlonglong)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 16 },
        }}),
        // Slot 'SetPosition'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, qlonglong)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::LongLong, 7 },
        }}),
        // Slot 'Stop'
        QtMocHelpers::SlotData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCanControlChanged'
        QtMocHelpers::SlotData<void() const>(21, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCanGoNextChanged'
        QtMocHelpers::SlotData<void() const>(22, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCanGoPreviousChanged'
        QtMocHelpers::SlotData<void() const>(23, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCanPauseChanged'
        QtMocHelpers::SlotData<void() const>(24, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCanPlayChanged'
        QtMocHelpers::SlotData<void() const>(25, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCanSeekChanged'
        QtMocHelpers::SlotData<void() const>(26, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onLoopStatusChanged'
        QtMocHelpers::SlotData<void() const>(27, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMaximumRateChanged'
        QtMocHelpers::SlotData<void() const>(28, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMetadataChanged'
        QtMocHelpers::SlotData<void() const>(29, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onMinimumRateChanged'
        QtMocHelpers::SlotData<void() const>(30, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onPlaybackStatusChanged'
        QtMocHelpers::SlotData<void() const>(31, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onRateChanged'
        QtMocHelpers::SlotData<void() const>(32, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShuffleChanged'
        QtMocHelpers::SlotData<void() const>(33, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onVolumeChanged'
        QtMocHelpers::SlotData<void() const>(34, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanControl'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanGoNext'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanGoPrevious'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanPause'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanPlay'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'CanSeek'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'LoopStatus'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'MaximumRate'
        QtMocHelpers::PropertyData<double>(42, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'Metadata'
        QtMocHelpers::PropertyData<QVariantMap>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'MinimumRate'
        QtMocHelpers::PropertyData<double>(45, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'PlaybackStatus'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Position'
        QtMocHelpers::PropertyData<qlonglong>(7, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'Rate'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Shuffle'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Volume'
        QtMocHelpers::PropertyData<double>(49, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MprisPlayerAdaptor, qt_meta_tag_ZN18MprisPlayerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MprisPlayerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MprisPlayerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MprisPlayerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18MprisPlayerAdaptorE_t>.metaTypes,
    nullptr
} };

void MprisPlayerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisPlayerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Seeked((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 1: _t->Next(); break;
        case 2: _t->OpenUri((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->Pause(); break;
        case 4: _t->Play(); break;
        case 5: _t->PlayPause(); break;
        case 6: _t->Previous(); break;
        case 7: _t->Seek((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 8: _t->SetPosition((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        case 9: _t->Stop(); break;
        case 10: _t->onCanControlChanged(); break;
        case 11: _t->onCanGoNextChanged(); break;
        case 12: _t->onCanGoPreviousChanged(); break;
        case 13: _t->onCanPauseChanged(); break;
        case 14: _t->onCanPlayChanged(); break;
        case 15: _t->onCanSeekChanged(); break;
        case 16: _t->onLoopStatusChanged(); break;
        case 17: _t->onMaximumRateChanged(); break;
        case 18: _t->onMetadataChanged(); break;
        case 19: _t->onMinimumRateChanged(); break;
        case 20: _t->onPlaybackStatusChanged(); break;
        case 21: _t->onRateChanged(); break;
        case 22: _t->onShuffleChanged(); break;
        case 23: _t->onVolumeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerAdaptor::*)(qlonglong )>(_a, &MprisPlayerAdaptor::Seeked, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canControl(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canGoPrevious(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canPause(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canSeek(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->loopStatus(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->maximumRate(); break;
        case 8: *reinterpret_cast<QVariantMap*>(_v) = _t->metadata(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->minimumRate(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->playbackStatus(); break;
        case 11: *reinterpret_cast<qlonglong*>(_v) = _t->position(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->rate(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->shuffle(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setLoopStatus(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setRate(*reinterpret_cast<double*>(_v)); break;
        case 13: _t->setShuffle(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MprisPlayerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisPlayerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MprisPlayerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MprisPlayerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void MprisPlayerAdaptor::Seeked(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
