// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_mpris.cpp"
#include "EWIEGA46WW/moc_mpriscontroller.cpp"
#include "EWIEGA46WW/moc_mpriscontroller_p.cpp"
#include "EWIEGA46WW/moc_mprismanager.cpp"
#include "EWIEGA46WW/moc_mprisplayer.cpp"
#include "EWIEGA46WW/moc_mprisplayer_p.cpp"
