/****************************************************************************
** Meta object code from reading C++ file 'mpriscontroller_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../audiotube-26.04.2/src/qtmpris/src/mpriscontroller_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mpriscontroller_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18MprisRootInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto MprisRootInterface::qt_create_metaobjectdata<qt_meta_tag_ZN18MprisRootInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MprisRootInterface",
        "canQuitChanged",
        "",
        "canQuit",
        "canRaiseChanged",
        "canRaise",
        "canSetFullscreenChanged",
        "canSetFullscreen",
        "desktopEntryChanged",
        "desktopEntry",
        "fullscreenChanged",
        "fullscreen",
        "hasTrackListChanged",
        "hasTrackList",
        "identityChanged",
        "identity",
        "supportedMimeTypesChanged",
        "supportedMimeTypes",
        "supportedUriSchemesChanged",
        "supportedUriSchemes",
        "Quit",
        "QDBusPendingReply<>",
        "Raise",
        "onPropertyChanged",
        "propertyName",
        "QVariant",
        "value",
        "CanQuit",
        "CanRaise",
        "CanSetFullscreen",
        "DesktopEntry",
        "Fullscreen",
        "HasTrackList",
        "Identity",
        "SupportedMimeTypes",
        "SupportedUriSchemes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'canQuitChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'canRaiseChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'canSetFullscreenChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'desktopEntryChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'hasTrackListChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'supportedMimeTypesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 17 },
        }}),
        // Signal 'supportedUriSchemesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 19 },
        }}),
        // Slot 'Quit'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(20, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'Raise'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(22, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 25, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanQuit'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'CanRaise'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'CanSetFullscreen'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'DesktopEntry'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'Fullscreen'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'HasTrackList'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'Identity'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'SupportedMimeTypes'
        QtMocHelpers::PropertyData<QStringList>(34, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'SupportedUriSchemes'
        QtMocHelpers::PropertyData<QStringList>(35, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MprisRootInterface, qt_meta_tag_ZN18MprisRootInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MprisRootInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<DBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MprisRootInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MprisRootInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18MprisRootInterfaceE_t>.metaTypes,
    nullptr
} };

void MprisRootInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisRootInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->canQuitChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->canRaiseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->canSetFullscreenChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->desktopEntryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->fullscreenChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->hasTrackListChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->identityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->supportedMimeTypesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->supportedUriSchemesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 9: { QDBusPendingReply<> _r = _t->Quit();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->Raise();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(bool )>(_a, &MprisRootInterface::canQuitChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(bool )>(_a, &MprisRootInterface::canRaiseChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(bool )>(_a, &MprisRootInterface::canSetFullscreenChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(const QString & )>(_a, &MprisRootInterface::desktopEntryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(bool )>(_a, &MprisRootInterface::fullscreenChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(bool )>(_a, &MprisRootInterface::hasTrackListChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(const QString & )>(_a, &MprisRootInterface::identityChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(const QStringList & )>(_a, &MprisRootInterface::supportedMimeTypesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisRootInterface::*)(const QStringList & )>(_a, &MprisRootInterface::supportedUriSchemesChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canQuit(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canRaise(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canSetFullscreen(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->desktopEntry(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hasTrackList(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->identity(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->supportedMimeTypes(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->supportedUriSchemes(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setFullscreen(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MprisRootInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisRootInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18MprisRootInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DBusExtendedAbstractInterface::qt_metacast(_clname);
}

int MprisRootInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void MprisRootInterface::canQuitChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MprisRootInterface::canRaiseChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MprisRootInterface::canSetFullscreenChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MprisRootInterface::desktopEntryChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MprisRootInterface::fullscreenChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MprisRootInterface::hasTrackListChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MprisRootInterface::identityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MprisRootInterface::supportedMimeTypesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void MprisRootInterface::supportedUriSchemesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN20MprisPlayerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto MprisPlayerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN20MprisPlayerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MprisPlayerInterface",
        "canControlChanged",
        "",
        "canControl",
        "canGoNextChanged",
        "canGoNext",
        "canGoPreviousChanged",
        "canGoPrevious",
        "canPauseChanged",
        "canPause",
        "canPlayChanged",
        "canPlay",
        "canSeekChanged",
        "canSeek",
        "loopStatusChanged",
        "loopStatus",
        "maximumRateChanged",
        "maximumRate",
        "metadataChanged",
        "QVariantMap",
        "metadata",
        "minimumRateChanged",
        "minimumRate",
        "playbackStatusChanged",
        "playbackStatus",
        "positionChanged",
        "rate",
        "rateChanged",
        "shuffleChanged",
        "shuffle",
        "volumeChanged",
        "volume",
        "seeked",
        "Position",
        "Next",
        "QDBusPendingReply<>",
        "OpenUri",
        "Uri",
        "Pause",
        "Play",
        "PlayPause",
        "Previous",
        "Seek",
        "Offset",
        "SetPosition",
        "QDBusObjectPath",
        "TrackId",
        "Stop",
        "onPropertyChanged",
        "propertyName",
        "QVariant",
        "value",
        "CanControl",
        "CanGoNext",
        "CanGoPrevious",
        "CanPause",
        "CanPlay",
        "CanSeek",
        "LoopStatus",
        "MaximumRate",
        "Metadata",
        "MinimumRate",
        "PlaybackStatus",
        "Rate",
        "Shuffle",
        "Volume"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'canControlChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'canGoNextChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'canGoPreviousChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'canPauseChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'canPlayChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'canSeekChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'loopStatusChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'maximumRateChanged'
        QtMocHelpers::SignalData<void(double)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 17 },
        }}),
        // Signal 'metadataChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'minimumRateChanged'
        QtMocHelpers::SignalData<void(double)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 22 },
        }}),
        // Signal 'playbackStatusChanged'
        QtMocHelpers::SignalData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(qlonglong)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 26 },
        }}),
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void(double)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 26 },
        }}),
        // Signal 'shuffleChanged'
        QtMocHelpers::SignalData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(double)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 31 },
        }}),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(qlonglong)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 33 },
        }}),
        // Slot 'Next'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(34, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'OpenUri'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'Pause'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(38, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'Play'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(39, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'PlayPause'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(40, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'Previous'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(41, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'Seek'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong)>(42, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { QMetaType::LongLong, 43 },
        }}),
        // Slot 'SetPosition'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, qlonglong)>(44, 2, QMC::AccessPublic, 0x80000000 | 35, {{
            { 0x80000000 | 45, 46 }, { QMetaType::LongLong, 33 },
        }}),
        // Slot 'Stop'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(47, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'onPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 49 }, { 0x80000000 | 50, 51 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'CanControl'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'CanGoNext'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'CanGoPrevious'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'CanPause'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'CanPlay'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'CanSeek'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'LoopStatus'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'MaximumRate'
        QtMocHelpers::PropertyData<double>(59, QMetaType::Double, QMC::DefaultPropertyFlags, 7),
        // property 'Metadata'
        QtMocHelpers::PropertyData<QVariantMap>(60, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
        // property 'MinimumRate'
        QtMocHelpers::PropertyData<double>(61, QMetaType::Double, QMC::DefaultPropertyFlags, 9),
        // property 'PlaybackStatus'
        QtMocHelpers::PropertyData<QString>(62, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'Position'
        QtMocHelpers::PropertyData<qlonglong>(33, QMetaType::LongLong, QMC::DefaultPropertyFlags, 11),
        // property 'Rate'
        QtMocHelpers::PropertyData<double>(63, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'Shuffle'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'Volume'
        QtMocHelpers::PropertyData<double>(65, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MprisPlayerInterface, qt_meta_tag_ZN20MprisPlayerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MprisPlayerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<DBusExtendedAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MprisPlayerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MprisPlayerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20MprisPlayerInterfaceE_t>.metaTypes,
    nullptr
} };

void MprisPlayerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisPlayerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->canControlChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->canGoNextChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->canGoPreviousChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->canPauseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->canPlayChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->canSeekChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->loopStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->maximumRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 8: _t->metadataChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 9: _t->minimumRateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->playbackStatusChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 12: _t->rateChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 13: _t->shuffleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 15: _t->seeked((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 16: { QDBusPendingReply<> _r = _t->Next();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->OpenUri((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->Pause();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->Play();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->PlayPause();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->Previous();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->Seek((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->SetPosition((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->Stop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->onPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(bool )>(_a, &MprisPlayerInterface::canControlChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(bool )>(_a, &MprisPlayerInterface::canGoNextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(bool )>(_a, &MprisPlayerInterface::canGoPreviousChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(bool )>(_a, &MprisPlayerInterface::canPauseChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(bool )>(_a, &MprisPlayerInterface::canPlayChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(bool )>(_a, &MprisPlayerInterface::canSeekChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(const QString & )>(_a, &MprisPlayerInterface::loopStatusChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(double )>(_a, &MprisPlayerInterface::maximumRateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(const QVariantMap & )>(_a, &MprisPlayerInterface::metadataChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(double )>(_a, &MprisPlayerInterface::minimumRateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(const QString & )>(_a, &MprisPlayerInterface::playbackStatusChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(qlonglong )>(_a, &MprisPlayerInterface::positionChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(double )>(_a, &MprisPlayerInterface::rateChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(bool )>(_a, &MprisPlayerInterface::shuffleChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(double )>(_a, &MprisPlayerInterface::volumeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayerInterface::*)(qlonglong )>(_a, &MprisPlayerInterface::seeked, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->canControl(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canGoPrevious(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canPause(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->canSeek(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->loopStatus(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->maximumRate(); break;
        case 8: *reinterpret_cast<QVariantMap*>(_v) = _t->metadata(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->minimumRate(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->playbackStatus(); break;
        case 11: *reinterpret_cast<qlonglong*>(_v) = _t->position(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->rate(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->shuffle(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setLoopStatus(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setRate(*reinterpret_cast<double*>(_v)); break;
        case 13: _t->setShuffle(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MprisPlayerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisPlayerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MprisPlayerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return DBusExtendedAbstractInterface::qt_metacast(_clname);
}

int MprisPlayerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DBusExtendedAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void MprisPlayerInterface::canControlChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MprisPlayerInterface::canGoNextChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MprisPlayerInterface::canGoPreviousChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MprisPlayerInterface::canPauseChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MprisPlayerInterface::canPlayChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MprisPlayerInterface::canSeekChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MprisPlayerInterface::loopStatusChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MprisPlayerInterface::maximumRateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void MprisPlayerInterface::metadataChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void MprisPlayerInterface::minimumRateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void MprisPlayerInterface::playbackStatusChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void MprisPlayerInterface::positionChanged(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void MprisPlayerInterface::rateChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void MprisPlayerInterface::shuffleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void MprisPlayerInterface::volumeChanged(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void MprisPlayerInterface::seeked(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
