/****************************************************************************
** Meta object code from reading C++ file 'mpriscontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../audiotube-26.04.2/src/qtmpris/src/mpriscontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mpriscontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15MprisControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto MprisController::qt_create_metaobjectdata<qt_meta_tag_ZN15MprisControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MprisController",
        "canQuitChanged",
        "",
        "canRaiseChanged",
        "canSetFullscreenChanged",
        "desktopEntryChanged",
        "fullscreenChanged",
        "hasTrackListChanged",
        "identityChanged",
        "supportedUriSchemesChanged",
        "supportedMimeTypesChanged",
        "canControlChanged",
        "canGoNextChanged",
        "canGoPreviousChanged",
        "canPauseChanged",
        "canPlayChanged",
        "canSeekChanged",
        "loopStatusChanged",
        "maximumRateChanged",
        "metadataChanged",
        "minimumRateChanged",
        "playbackStatusChanged",
        "positionChanged",
        "position",
        "rateChanged",
        "shuffleChanged",
        "volumeChanged",
        "seeked",
        "service",
        "canQuit",
        "canRaise",
        "canSetFullscreen",
        "desktopEntry",
        "fullscreen",
        "setFullscreen",
        "hasTrackList",
        "identity",
        "supportedUriSchemes",
        "supportedMimeTypes",
        "canControl",
        "canGoNext",
        "canGoPrevious",
        "canPause",
        "canPlay",
        "canSeek",
        "loopStatus",
        "Mpris::LoopStatus",
        "setLoopStatus",
        "maximumRate",
        "metadata",
        "QVariantMap",
        "minimumRate",
        "playbackStatus",
        "Mpris::PlaybackStatus",
        "requestPosition",
        "rate",
        "setRate",
        "shuffle",
        "setShuffle",
        "volume",
        "setVolume",
        "onAsyncGetAllRootPropertiesFinished",
        "onAsyncGetAllPlayerPropertiesFinished",
        "onCanControlChanged",
        "onPositionChanged",
        "aPosition",
        "onFinishedPendingCall",
        "QDBusPendingCallWatcher*",
        "call"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'canQuitChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canRaiseChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSetFullscreenChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopEntryChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasTrackListChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedUriSchemesChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedMimeTypesChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canControlChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoNextChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoPreviousChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPauseChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPlayChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSeekChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loopStatusChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumRateChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'metadataChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumRateChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playbackStatusChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(qlonglong)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 23 },
        }}),
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuffleChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(qlonglong)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 23 },
        }}),
        // Slot 'service'
        QtMocHelpers::SlotData<QString() const>(28, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'canQuit'
        QtMocHelpers::SlotData<bool() const>(29, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canRaise'
        QtMocHelpers::SlotData<bool() const>(30, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canSetFullscreen'
        QtMocHelpers::SlotData<bool() const>(31, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'desktopEntry'
        QtMocHelpers::SlotData<QString() const>(32, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'fullscreen'
        QtMocHelpers::SlotData<bool() const>(33, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setFullscreen'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'hasTrackList'
        QtMocHelpers::SlotData<bool() const>(35, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'identity'
        QtMocHelpers::SlotData<QString() const>(36, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'supportedUriSchemes'
        QtMocHelpers::SlotData<QStringList() const>(37, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'supportedMimeTypes'
        QtMocHelpers::SlotData<QStringList() const>(38, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'canControl'
        QtMocHelpers::SlotData<bool() const>(39, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canGoNext'
        QtMocHelpers::SlotData<bool() const>(40, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canGoPrevious'
        QtMocHelpers::SlotData<bool() const>(41, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canPause'
        QtMocHelpers::SlotData<bool() const>(42, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canPlay'
        QtMocHelpers::SlotData<bool() const>(43, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canSeek'
        QtMocHelpers::SlotData<bool() const>(44, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'loopStatus'
        QtMocHelpers::SlotData<Mpris::LoopStatus() const>(45, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'setLoopStatus'
        QtMocHelpers::SlotData<void(Mpris::LoopStatus)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 45 },
        }}),
        // Slot 'maximumRate'
        QtMocHelpers::SlotData<double() const>(48, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'metadata'
        QtMocHelpers::SlotData<QVariantMap() const>(49, 2, QMC::AccessPublic, 0x80000000 | 50),
        // Slot 'minimumRate'
        QtMocHelpers::SlotData<double() const>(51, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'playbackStatus'
        QtMocHelpers::SlotData<Mpris::PlaybackStatus() const>(52, 2, QMC::AccessPublic, 0x80000000 | 53),
        // Slot 'position'
        QtMocHelpers::SlotData<qlonglong() const>(23, 2, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'requestPosition'
        QtMocHelpers::SlotData<void() const>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rate'
        QtMocHelpers::SlotData<double() const>(55, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'setRate'
        QtMocHelpers::SlotData<void(double)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 55 },
        }}),
        // Slot 'shuffle'
        QtMocHelpers::SlotData<bool() const>(57, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShuffle'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 57 },
        }}),
        // Slot 'volume'
        QtMocHelpers::SlotData<double() const>(59, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(double)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 59 },
        }}),
        // Slot 'onAsyncGetAllRootPropertiesFinished'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onAsyncGetAllPlayerPropertiesFinished'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onCanControlChanged'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onPositionChanged'
        QtMocHelpers::SlotData<void(qlonglong)>(64, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::LongLong, 65 },
        }}),
        // Slot 'onFinishedPendingCall'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(66, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 67, 68 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'service'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'canQuit'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'canRaise'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'canSetFullscreen'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'desktopEntry'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'fullscreen'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'hasTrackList'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'identity'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'supportedUriSchemes'
        QtMocHelpers::PropertyData<QStringList>(37, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'supportedMimeTypes'
        QtMocHelpers::PropertyData<QStringList>(38, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
        // property 'canControl'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'canGoNext'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'canGoPrevious'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'canPause'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'canPlay'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 13),
        // property 'canSeek'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 14),
        // property 'loopStatus'
        QtMocHelpers::PropertyData<Mpris::LoopStatus>(45, 0x80000000 | 46, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
        // property 'maximumRate'
        QtMocHelpers::PropertyData<double>(48, QMetaType::Double, QMC::DefaultPropertyFlags, 16),
        // property 'metadata'
        QtMocHelpers::PropertyData<QVariantMap>(49, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 17),
        // property 'minimumRate'
        QtMocHelpers::PropertyData<double>(51, QMetaType::Double, QMC::DefaultPropertyFlags, 18),
        // property 'playbackStatus'
        QtMocHelpers::PropertyData<Mpris::PlaybackStatus>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 19),
        // property 'position'
        QtMocHelpers::PropertyData<qlonglong>(23, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'rate'
        QtMocHelpers::PropertyData<double>(55, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'shuffle'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'volume'
        QtMocHelpers::PropertyData<double>(59, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MprisController, qt_meta_tag_ZN15MprisControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN15MprisControllerE[] = {
    QMetaObject::SuperData::link<Mpris::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject MprisController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MprisControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MprisControllerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN15MprisControllerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15MprisControllerE_t>.metaTypes,
    nullptr
} };

void MprisController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->canQuitChanged(); break;
        case 1: _t->canRaiseChanged(); break;
        case 2: _t->canSetFullscreenChanged(); break;
        case 3: _t->desktopEntryChanged(); break;
        case 4: _t->fullscreenChanged(); break;
        case 5: _t->hasTrackListChanged(); break;
        case 6: _t->identityChanged(); break;
        case 7: _t->supportedUriSchemesChanged(); break;
        case 8: _t->supportedMimeTypesChanged(); break;
        case 9: _t->canControlChanged(); break;
        case 10: _t->canGoNextChanged(); break;
        case 11: _t->canGoPreviousChanged(); break;
        case 12: _t->canPauseChanged(); break;
        case 13: _t->canPlayChanged(); break;
        case 14: _t->canSeekChanged(); break;
        case 15: _t->loopStatusChanged(); break;
        case 16: _t->maximumRateChanged(); break;
        case 17: _t->metadataChanged(); break;
        case 18: _t->minimumRateChanged(); break;
        case 19: _t->playbackStatusChanged(); break;
        case 20: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 21: _t->rateChanged(); break;
        case 22: _t->shuffleChanged(); break;
        case 23: _t->volumeChanged(); break;
        case 24: _t->seeked((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 25: { QString _r = _t->service();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->canQuit();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->canRaise();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->canSetFullscreen();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { QString _r = _t->desktopEntry();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->fullscreen();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->setFullscreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: { bool _r = _t->hasTrackList();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { QString _r = _t->identity();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 34: { QStringList _r = _t->supportedUriSchemes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 35: { QStringList _r = _t->supportedMimeTypes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->canControl();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->canGoNext();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->canGoPrevious();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { bool _r = _t->canPause();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 40: { bool _r = _t->canPlay();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->canSeek();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { Mpris::LoopStatus _r = _t->loopStatus();
            if (_a[0]) *reinterpret_cast<Mpris::LoopStatus*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->setLoopStatus((*reinterpret_cast<std::add_pointer_t<Mpris::LoopStatus>>(_a[1]))); break;
        case 44: { double _r = _t->maximumRate();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 45: { QVariantMap _r = _t->metadata();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 46: { double _r = _t->minimumRate();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 47: { Mpris::PlaybackStatus _r = _t->playbackStatus();
            if (_a[0]) *reinterpret_cast<Mpris::PlaybackStatus*>(_a[0]) = std::move(_r); }  break;
        case 48: { qlonglong _r = _t->position();
            if (_a[0]) *reinterpret_cast<qlonglong*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->requestPosition(); break;
        case 50: { double _r = _t->rate();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->setRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 52: { bool _r = _t->shuffle();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->setShuffle((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 54: { double _r = _t->volume();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->setVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 56: _t->onAsyncGetAllRootPropertiesFinished(); break;
        case 57: _t->onAsyncGetAllPlayerPropertiesFinished(); break;
        case 58: _t->onCanControlChanged(); break;
        case 59: _t->onPositionChanged((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 60: _t->onFinishedPendingCall((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canQuitChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canRaiseChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canSetFullscreenChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::desktopEntryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::fullscreenChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::hasTrackListChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::identityChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::supportedUriSchemesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::supportedMimeTypesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canControlChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canGoNextChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canGoPreviousChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canPauseChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canPlayChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::canSeekChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::loopStatusChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::maximumRateChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::metadataChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::minimumRateChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::playbackStatusChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)(qlonglong )>(_a, &MprisController::positionChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::rateChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::shuffleChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)()>(_a, &MprisController::volumeChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisController::*)(qlonglong )>(_a, &MprisController::seeked, 24))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->service(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canQuit(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canRaise(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canSetFullscreen(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->desktopEntry(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasTrackList(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->identity(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->supportedUriSchemes(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->supportedMimeTypes(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->canControl(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->canGoPrevious(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->canPause(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->canSeek(); break;
        case 16: *reinterpret_cast<Mpris::LoopStatus*>(_v) = _t->loopStatus(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->maximumRate(); break;
        case 18: *reinterpret_cast<QVariantMap*>(_v) = _t->metadata(); break;
        case 19: *reinterpret_cast<double*>(_v) = _t->minimumRate(); break;
        case 20: *reinterpret_cast<Mpris::PlaybackStatus*>(_v) = _t->playbackStatus(); break;
        case 21: *reinterpret_cast<qlonglong*>(_v) = _t->position(); break;
        case 22: *reinterpret_cast<double*>(_v) = _t->rate(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->shuffle(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setFullscreen(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setLoopStatus(*reinterpret_cast<Mpris::LoopStatus*>(_v)); break;
        case 22: _t->setRate(*reinterpret_cast<double*>(_v)); break;
        case 23: _t->setShuffle(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MprisController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MprisControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MprisController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 61)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 61;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void MprisController::canQuitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MprisController::canRaiseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MprisController::canSetFullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MprisController::desktopEntryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MprisController::fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MprisController::hasTrackListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MprisController::identityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MprisController::supportedUriSchemesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MprisController::supportedMimeTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MprisController::canControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MprisController::canGoNextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MprisController::canGoPreviousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MprisController::canPauseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MprisController::canPlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void MprisController::canSeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void MprisController::loopStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void MprisController::maximumRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void MprisController::metadataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void MprisController::minimumRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void MprisController::playbackStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void MprisController::positionChanged(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void MprisController::rateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void MprisController::shuffleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void MprisController::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void MprisController::seeked(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}
QT_WARNING_POP
