/****************************************************************************
** Meta object code from reading C++ file 'playlistimporter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../audiotube-26.04.2/src/playlistimporter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlistimporter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16PlaylistImporterE_t {};
} // unnamed namespace

template <> constexpr inline auto PlaylistImporter::qt_create_metaobjectdata<qt_meta_tag_ZN16PlaylistImporterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlaylistImporter",
        "QML.Element",
        "auto",
        "importFinished",
        "",
        "playlistEntriesChanged",
        "playlistId",
        "refreshModel",
        "importPlaylist",
        "url",
        "addPlaylistEntry",
        "videoId",
        "title",
        "artist",
        "album",
        "playlist::Track",
        "track",
        "renamePlaylist",
        "name",
        "description"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'importFinished'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playlistEntriesChanged'
        QtMocHelpers::SignalData<void(quint64)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 6 },
        }}),
        // Signal 'refreshModel'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'importPlaylist'
        QtMocHelpers::MethodData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'addPlaylistEntry'
        QtMocHelpers::MethodData<void(qint64, const QString &, const QString &, const QString &, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
            { QMetaType::QString, 14 },
        }}),
        // Method 'addPlaylistEntry'
        QtMocHelpers::MethodData<void(qint64, const playlist::Track &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'renamePlaylist'
        QtMocHelpers::MethodData<void(qint64, const QString &, const QString &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PlaylistImporter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PlaylistImporter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PlaylistImporterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PlaylistImporterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16PlaylistImporterE_t>.metaTypes,
    nullptr
} };

void PlaylistImporter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlaylistImporter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->importFinished(); break;
        case 1: _t->playlistEntriesChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 2: _t->refreshModel(); break;
        case 3: _t->importPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->addPlaylistEntry((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 5: _t->addPlaylistEntry((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<playlist::Track>>(_a[2]))); break;
        case 6: _t->renamePlaylist((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlaylistImporter::*)()>(_a, &PlaylistImporter::importFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistImporter::*)(quint64 )>(_a, &PlaylistImporter::playlistEntriesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistImporter::*)()>(_a, &PlaylistImporter::refreshModel, 2))
            return;
    }
}

const QMetaObject *PlaylistImporter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistImporter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PlaylistImporterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PlaylistImporter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void PlaylistImporter::importFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlaylistImporter::playlistEntriesChanged(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PlaylistImporter::refreshModel()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
